@@ -12,15 +12,6 @@ c2 = '#f77f0e'
 c3 = '#2ca02c'
 
 
-def savefigure(prefix = './'):
-  
-
- namefile =  prefix + sys.argv[0].split('.')[0]+'.png'
- 
- savefig(namefile,dpi=300)
-
-
-
 def init_plotting(extra_x_padding = 0.0,extra_y_padding=0.0,extra_bottom_padding = 0.0,extra_top_padding=  0.0,paraview=False,square=False,delta_square = 0,presentation=False):
 
  rc('font',**{'family':'serif','serif':['Computer Modern Roman']})
@@ -57,17 +48,7 @@ def init_plotting(extra_x_padding = 0.0,extra_y_padding=0.0,extra_bottom_padding
  rcParams['ytick.minor.width'] = 1
  rcParams['legend.frameon'] = False
  rcParams['legend.fontsize'] = 25
- #rcParams['legend.loc'] = 'center left'
  rcParams['axes.linewidth'] = 1
- #rcParams['axes.spines.top'] = False
- #rcParams['axes.spines.right'] = False
- #rcParams['axes.xmargin'] = 0.20
- #rcParams['axes.ymargin'] = 0.20
- #rcParams['axes.margins.tight'] = True
- #gca().spines['right'].set_color('none')
- #gca().spines['top'].set_color('none')
- #gca().xaxis.set_ticks_position('bottom')
- #gca().yaxis.set_ticks_position('left')i
  if paraview or presentation:
   axes([delta_square,delta_square,1-2.0*delta_square,1-2.0*delta_square])
  else:
