@@ -8,6 +8,8 @@ from builtins import range
 from past.builtins import basestring
 from builtins import object
 from past.utils import old_div
+
+
 from .common_fig import *
 import os,shutil
 import matplotlib.image as mpimg
@@ -20,9 +22,20 @@ from collections import OrderedDict
 import pickle as pickle
 import sys
 import urllib.request, urllib.parse, urllib.error
-#from matplotlib.pylab import *
+
+import argparse
+parser = argparse.ArgumentParser()
+parser.add_argument('-o', help='output file',default='slides.pdf')
+args = parser.parse_args()
+
+global output_name 
+output_name = args.o
+
 init_plotting(presentation=True)
 
+
+
+
 class Presentation(object):
 
  def __init__(self,**argv):
@@ -101,11 +114,11 @@ class Presentation(object):
 
  def get_next_m(self):
 
-  files = os.listdir('tmp')
+  files = os.listdir('.cache')
   exist = True
   m = 0
   while exist:
-   if not os.path.isfile('tmp/slide_' + str(m) + '.pdf'): 
+   if not os.path.isfile('.cache/slide_' + str(m) + '.pdf'): 
     return m
    m +=1  
 
@@ -113,18 +126,19 @@ class Presentation(object):
  def render(self):
 
   #Create directory---------------
-  directory = 'tmp'
+  directory = '.cache'
   if not os.path.exists(directory):
    os.makedirs(directory)
    #shutil.rmtree(directory)
  
   #load database--------------
-  if os.path.isfile('tmp/slides.p'): 
-   with open('tmp/slides.p') as f:
+  if os.path.isfile('.cache/slides.p'): 
+   with open('.cache/slides.p') as f:
     slides_db = pickle.load(f)
   else:
    slides_db = {}
- 
+
+
   slides_db_new = {}
   #--------------------------
   #-------
@@ -140,8 +154,8 @@ class Presentation(object):
       if slide_db == slide:
        slides_db_new.update({m:slide})
        n += 1
-       print('Include ' + str(n))
-       list_files.append('tmp/slide_' + str(m) + '.pdf')
+       print('Include slide ' + str(n))
+       list_files.append('.cache/slide_' + str(m) + '.pdf')
        exist = True
        break
 
@@ -152,11 +166,11 @@ class Presentation(object):
       print('Compile slide ' + str(n))
       slides_db_new.update({m:slide})
       
-      savefig('tmp/slide_' + str(m) + '.pdf',dpi=500)  
+      savefig('.cache/slide_' + str(m) + '.pdf',dpi=500)  
       #savefig('tmp/slide_' + str(m) + '.pdf',dpi=100)  
-      list_files.append('tmp/slide_' + str(m) + '.pdf')
+      list_files.append('.cache/slide_' + str(m) + '.pdf')
 
-  with open('tmp/slides.p', 'wb+') as f:
+  with open('.cache/slides.p', 'wb+') as f:
       pickle.dump(slides_db_new, f)
   #--------------------------
 
@@ -164,8 +178,8 @@ class Presentation(object):
   #Create final presentation---------    
   merger = PdfFileMerger()
   for filename in list_files:
-   merger.append(PdfFileReader(file(filename, 'rb')))
-  namefile =  'slides.pdf'
+   merger.append(PdfFileReader(open(filename, 'rb')))
+  namefile =  output_name
 
   merger.write(namefile)
 
@@ -186,7 +200,7 @@ class Presentation(object):
  def reorder_database(self):
   
   #update slides-------------------------
-  with open('tmp/slides.p','rb') as f:
+  with open('.cache/slides.p','rb') as f:
    slides_db = pickle.load(f)
 
   slides_db_new = {}
@@ -196,21 +210,22 @@ class Presentation(object):
    old_index = list(slides_db.keys())[m]
 
    slides_db_new.update({i:slides_db[old_index]})
-   os.system('mv tmp/slide_' + str(old_index) + '.pdf' + ' tmp/slide_tmp_' + str(i) + '.pdf' )
+   os.system('mv .cache/slide_' + str(old_index) + '.pdf' + ' .cache/slide_tmp_' + str(i) + '.pdf' )
 
   #reordering
-  files = os.listdir('tmp')
+  files = os.listdir('.cache')
   for f in files:
    if len(f.split('_')) > 2:
     n = f.split('_')[2].split('.')[0]
-    os.system('mv tmp/slide_tmp_' + str(n) + '.pdf' + ' tmp/slide_' + str(n)  + '.pdf')
+    os.system('mv .cache/slide_tmp_' + str(n) + '.pdf' + ' .cache/slide_' + str(n)  + '.pdf')
   
   #write new database  
-  with open('tmp/slides.p', 'wb+') as f:
+  with open('.cache/slides.p', 'wb+') as f:
     pickle.dump(slides_db_new, f)
 
  def render_slide(self,slide):
 
+ 
   close()
   init_plotting(presentation=True)
 
